using UnityEngine;
using System.Collections;

public class CleaningServiceEvent : MonoBehaviour
{
	public GUISkin skin;
	public PlayerController player;
	public AudioClip eventSound;
	
	void Start()
	{
		player = FindObjectOfType(typeof(PlayerController)) as PlayerController;
		if(player == null)
		{
			Destroy(this.gameObject);
			return;
		}
		
		if(eventSound != null)
		{
			AudioSource.PlayClipAtPoint(eventSound, Vector3.zero, 0.5f);
		}
		
		skin = player.skin;
	}
	
	void OnGUI ()
	{
		Time.timeScale = 0.0f;
		
		float scaleFactor = Screen.height / 1000.0f;
		GUI.matrix = Matrix4x4.TRS (new Vector3(Screen.width / 2.0f, Screen.height / 2.0f, 0.0f), Quaternion.identity, new Vector3 (scaleFactor, scaleFactor, 1.0f)); 

		if(skin)
		{
			GUI.skin = skin;
		}
		else
		{
			Debug.Log("GUI skin object missing.");
		}

		GUI.TextArea(new Rect(-510f, -110f, 1020f, 200f), "");
		GUI.Label(new Rect(-500f, -100f, 1000f, 60f), "Hello, this is General Cleaning Service. For a $200 fee,", "CenterLabel");
		GUI.Label(new Rect(-500f, -40f, 1000f, 60f), "we can remove up to 20 low-value junk items.", "CenterLabel");
		GUI.Label(new Rect(-500f, 20f, 1000f, 60f), "would you like to use our services?", "CenterLabel");
		
		if(GUI.Button(new Rect(-250f, 200f, 200f, 100f), "Yes"))
		{
			if(player.money >= 200)
			{
				player.money -= 200;
				player.PlayMoneySound();
				RemoveJunk();
				
				Time.timeScale = 1.0f;
				Destroy(this.gameObject);
			}
			else
			{
				player.SetErrorMessage("I can't afford to pay for cleaning service.");
			}
		}

		if(GUI.Button(new Rect(50f, 200f, 200f, 100f), "No"))
		{
			Time.timeScale = 1.0f;
			Destroy(this.gameObject);
		}
		
	}
	
	private void RemoveJunk() 
	{
		int countRemoved = 0;
		int oldScore = player.score;
		var junkItems = FindObjectsOfType(typeof(Junk));
		
		foreach(var junkObj in junkItems)
		{
			var junk = junkObj as Junk;
			if(junk.money <= 1)
			{
				junk.CleaningServiceGetRidOfIt();
				countRemoved++;

				if(countRemoved >= 20)
				{
					break;
				}
			}
		}
		
		player.SetGameMessage("Cleaning service increases score by " + (player.score - oldScore));
	}
}
