using UnityEngine;
using System.Collections;

public class DayNightCycle : MonoBehaviour
{
	public GUISkin skin;
	public Light sunLight;
	public PlayerController player;
	public JunkSpawner spawner;
	public float secondsPerDay = 180f;
	public float timeOfDay;
	public int dayNumber = 1;
	public bool dayComplete;
	public bool specialEventCheckDone = false;
	public int moneySpend;
	public GameObject[] specialEvents;
	public float specialEventChance = 0.33f;
	public AudioClip dayDoneSound;
	
	// Use this for initialization
	void OnGUI ()
	{
		float scaleFactor = Screen.height / 1000.0f;
		GUI.matrix = Matrix4x4.TRS (new Vector3(Screen.width / 2.0f, Screen.height / 2.0f, 0.0f), Quaternion.identity, new Vector3 (scaleFactor, scaleFactor, 1.0f)); 

		if(skin)
		{
			GUI.skin = skin;
		}
		else
		{
			Debug.Log("GUI skin object missing.");
		}

		var hour = (int)((timeOfDay / secondsPerDay) * 12f + 7f);
		var hour12 = hour % 12;
		var hourString = (hour12 == 0 ? "12" : hour12.ToString()) + (hour < 12 ? "am" : "pm");
		GUI.Label(new Rect(465f, -485f, 320f, 80f), "", "textArea");
		GUI.Label(new Rect(475f, -475f, 300f, 60f), "Day " + dayNumber + ", " + hourString, "RightLabel");
		
		if(dayComplete)
		{
			GUI.Label(new Rect(-510f, -110f, 1020f, 260f), "", "textArea");
			if(moneySpend > 0)
			{
				GUI.Label(new Rect(-500f, -100f, 1000f, 60f), "At night, a compulsion to buy more stuff takes hold.", "CenterLabel");
				GUI.Label(new Rect(-500f, -40f, 1000f, 60f), "You spent " + moneySpend.ToString("C0") + " on more junk.", "CenterLabel");
			}
			else
			{
				GUI.Label(new Rect(-500f, -100f, 1000f, 60f), "You have no money to buy new junk tonight.", "CenterLabel");
				GUI.Label(new Rect(-500f, -40f, 1000f, 60f), "That's probably for the best.", "CenterLabel");
			}
			GUI.Label(new Rect(-500f, 80f, 1000f, 60f), "You earned $100 from work today.", "CenterLabel");
			
			if(GUI.Button(new Rect(-150f, 200f, 300f, 100f), "Next Day"))
			{
				timeOfDay = 0f;
				++dayNumber;
				dayComplete = false;
				specialEventCheckDone = false;
				Time.timeScale = 1.0f;
			}
		}
	}
	
	// Update is called once per frame
	void Update () 
	{
		timeOfDay += Time.deltaTime;
		
		sunLight.transform.localRotation = GetDayRotation();
		RenderSettings.ambientLight = GetDayLightAmbientColor();
		light.color = GetSunColor();
		
		if(!specialEventCheckDone && timeOfDay >= secondsPerDay * 0.5f)
		{
			if(Random.value < specialEventChance)
			{
				int index = Random.Range(0, dayNumber > 1 ? specialEvents.Length : specialEvents.Length - 1);
				
				Instantiate(specialEvents[index]);
			}
			
			specialEventCheckDone = true;
		}
		
		
		if(timeOfDay >= secondsPerDay && !dayComplete)
		{
			AudioSource.PlayClipAtPoint(dayDoneSound, Vector3.zero, 1.0f);
			Time.timeScale = 0.0f;
			dayComplete = true;
			
			var moneySpendPercent = Random.Range(0.1f, 0.9f);
			moneySpend = (int)(player.money * moneySpendPercent);
			
			if(moneySpend > 0)
			{
				var newClutter = spawner.SpawnByValue(moneySpend);
				player.money -= moneySpend;
				player.score -= newClutter;
				player.SetGameMessage("New clutter reduces score by " + newClutter);
			}
			
			player.money += 100;
		}
	
	}
	
	private Quaternion GetDayRotation()
	{
		return Quaternion.Euler(20f + (140f * timeOfDay / secondsPerDay), 330f, 0f);
	}
	
	private Color GetDayLightAmbientColor()
	{
		float percent = timeOfDay / secondsPerDay;
		float t = Mathf.Abs(percent * 2f - 1f);
		
		return Color.Lerp(new Color(0.25f, 0.25f, 0.15f), new Color(0.0625f, 0.0625f, 0.125f), t);
	}

	private Color GetSunColor()
	{
		float percent = timeOfDay / secondsPerDay;
		float t = Mathf.Abs(percent * 2f - 1f);
		
		return Color.Lerp(new Color(1.0f, 1.0f, 0.85f), new Color(1.0f, 0.75f, 0.75f), t);
	}
}
