using UnityEngine;
using System.Collections;

public class GoalCollectionEvent : MonoBehaviour
{
	public GUISkin skin;
	public PlayerController player;
	public AudioClip eventSound;
	
	void Start()
	{
		player = FindObjectOfType(typeof(PlayerController)) as PlayerController;
		if(player == null)
		{
			Destroy(this.gameObject);
			return;
		}
		
		if(eventSound != null)
		{
			AudioSource.PlayClipAtPoint(eventSound, Vector3.zero, 0.5f);
		}

		skin = player.skin;
		SetGoal();
	}
	
	void OnGUI ()
	{
		Time.timeScale = 0.0f;
		
		float scaleFactor = Screen.height / 1000.0f;
		GUI.matrix = Matrix4x4.TRS (new Vector3(Screen.width / 2.0f, Screen.height / 2.0f, 0.0f), Quaternion.identity, new Vector3 (scaleFactor, scaleFactor, 1.0f)); 

		if(skin)
		{
			GUI.skin = skin;
		}
		else
		{
			Debug.Log("GUI skin object missing.");
		}

		GUI.TextArea(new Rect(-510f, -110f, 1020f, 200f), "");
		GUI.Label(new Rect(-500f, -100f, 1000f, 60f), "Hello, I need " + player.goalCountRemaining + " " + player.goalJunkType + "s", "CenterLabel");
		GUI.Label(new Rect(-500f, -40f, 1000f, 60f), "for a project, and I heard you might be able to help.", "CenterLabel");
		GUI.Label(new Rect(-500f, 20f, 1000f, 60f), "Can you spare some? (Timed, awards 250 bonus points)", "CenterLabel");
		
		if(GUI.Button(new Rect(-150f, 200f, 300f, 100f), "I'll Check"))
		{
			Time.timeScale = 1.0f;
			Destroy(this.gameObject);
		}
	}
	
	private void SetGoal() 
	{
		if(player.willingness < 20)
		{
			player.goalJunkType = "Cup";
			player.goalCountRemaining = 20;
			player.goalTimeRemaining = 30f;
		}
		else if(player.willingness < 35)
		{
			player.goalJunkType = "Soda Bottle";
			player.goalCountRemaining = 15;
			player.goalTimeRemaining = 30f;
		}
		else if(player.willingness < 60)
		{
			player.goalJunkType = "Newspaper";
			player.goalCountRemaining = 25;
			player.goalTimeRemaining = 30f;
		}
		else if(player.willingness < 135)
		{
			player.goalJunkType = "Faded Jeans";
			player.goalCountRemaining = 10;
			player.goalTimeRemaining = 30f;
		}
		else if(player.willingness < 260)
		{
			player.goalJunkType = "Radio";
			player.goalCountRemaining = 10;
			player.goalTimeRemaining = 30f;
		}
		else
		{
			player.goalJunkType = "TV";
			player.goalCountRemaining = 5;
			player.goalTimeRemaining = 20f;
		}
	}
}
