using UnityEngine;
using System.Collections;

public class InspectionEvent : MonoBehaviour
{
	public GUISkin skin;
	public PlayerController player;
	public AudioClip eventSound;
	
	void Start()
	{
		player = FindObjectOfType(typeof(PlayerController)) as PlayerController;
		if(player == null)
		{
			Destroy(this.gameObject);
			return;
		}
		
		if(eventSound != null)
		{
			AudioSource.PlayClipAtPoint(eventSound, Vector3.zero, 0.5f);
		}
		
		skin = player.skin;
	}
	
	void OnGUI ()
	{
		Time.timeScale = 0.0f;
		
		float scaleFactor = Screen.height / 1000.0f;
		GUI.matrix = Matrix4x4.TRS (new Vector3(Screen.width / 2.0f, Screen.height / 2.0f, 0.0f), Quaternion.identity, new Vector3 (scaleFactor, scaleFactor, 1.0f)); 

		if(skin)
		{
			GUI.skin = skin;
		}
		else
		{
			Debug.Log("GUI skin object missing.");
		}

		GUI.TextArea(new Rect(-610f, -110f, 1220f, 200f), "");
		GUI.Label(new Rect(-500f, -100f, 1000f, 60f), "Hello, this is the city building inspector. We've received", "CenterLabel");
		GUI.Label(new Rect(-500f, -40f, 1000f, 60f), "numerous complaints about your property. You can pay a fine", "CenterLabel");
		GUI.Label(new Rect(-500f, 20f, 1000f, 60f), "of $250, or have your score reduced by 1,000.", "CenterLabel");
		
		if(GUI.Button(new Rect(-350f, 200f, 300f, 100f), "Pay Fine"))
		{
			if(player.money >= 250)
			{
				player.money -= 250;
				player.PlayMoneySound();

				Time.timeScale = 1.0f;
				Destroy(this.gameObject);
			}
			else
			{
				player.SetErrorMessage("I don't have enough money to pay the fine.");
			}
		}

		if(GUI.Button(new Rect(50f, 200f, 300f, 100f), "- Score"))
		{
			player.score -= 1000;
			
			Time.timeScale = 1.0f;
			Destroy(this.gameObject);
		}
		
	}
}
