using UnityEngine;
using System.Collections;

public class PlayerController : MonoBehaviour 
{
	public float walkSpeed;
	public float turnSpeed;
	public int winScore = 10000;
	public GUISkin skin;
	public AudioClip trashSound;
	public AudioClip errorSound;
	public AudioClip moneySound;
	public AudioClip bonusSound;
	
	public int willingness;
	public int money;
	public int score;
	public float winTime;
	
	public Junk selectedJunk;
	public string errorMessage;
	public float errorTimer;
	public string feelingMessage;
	public float heading;
	public float pitch;
	
	public string goalJunkType;
	public float goalTimeRemaining;
	public int goalCountRemaining;
	
	public string gameMessage;
	public float gameMessageTimer;
	
	private bool firstFrame = true;
	
	private Vector2 lastMousePosition;
	
	public string[] needMessages = new string[] {
		"I think I'll need this later.",
		"I really don't want to get rid of this.",
		"I'm going to use that for a project.",
		"I don't think I can do without that."
	};
	
	public string[] sellMessages = new string[] {
		"For the right price, I can part with that.",
		"Maybe this can go on eJunk.",
		"I don't really want to lose this, but I could use the money.",
		"Hmm. Maybe I should sell this."
	};

	public string[] trashMessages = new string[] {
		"I'm ready to part with this.",
		"Let's go ahead and throw this away.",
		"What purpose was this serving again?",
		"Maybe this should go in the trash."
	};

	public string[] willDownMessages = new string[] {
		"I think I need to think about this one more.",
		"I'd like to keep this. For now.",
		"If I still haven't used this in a bit, maybe I'll get rid of it.",
		"I'm really torn about getting rid of this."
	};

	// Use this for initialization
	void Start () {
	
	}
	
	void FixedUpdate()
	{
		if(Time.timeScale == 0.0f)
		{
			firstFrame = true;
		}
	}
	
	// Update is called once per frame
	void Update()
	{
		errorTimer -= Time.deltaTime;
		gameMessageTimer -= Time.deltaTime;
		
		if(goalTimeRemaining > 0f)
		{
			goalTimeRemaining -= Time.deltaTime;
			if(goalCountRemaining <= 0)
			{
				SetGameMessage("Goal Completed! 250 bonus points awarded.");
				PlayBonusSound();
				goalTimeRemaining = 0f;
				score += 250;
			}
		}

		if(selectedJunk == null)
		{
			errorTimer = 0f;
			
			float walkRaw = Input.GetAxis("Vertical");
			float turnRaw = Input.GetAxis("Horizontal");
			float pitchRawMouse = 0f;
			float turnRawMouse = 0f;
			
			if(Input.GetMouseButton(1) || Input.GetMouseButton(2))
			{
				turnRawMouse += (Input.mousePosition.x - lastMousePosition.x) / 8f;
				pitchRawMouse += (Input.mousePosition.y - lastMousePosition.y) / 8f;
			}
			lastMousePosition = Input.mousePosition;
			
			if(Mathf.Abs(turnRaw) > 0.3f)
			{
				heading += turnSpeed * Time.deltaTime * Mathf.Sign(turnRaw);
			}
			
			if(Mathf.Abs(turnRawMouse) > 0.3f)
			{
				heading += turnSpeed * Time.deltaTime * turnRawMouse;
			}
			
			if(Mathf.Abs(walkRaw) > 0.3f)
			{
				transform.position += Quaternion.Euler(0f, heading, 0f) * (Vector3.forward * walkSpeed * Time.deltaTime * Mathf.Sign(walkRaw));
			}
			
			if(transform.position.x < -3.6f)
			{
				transform.position = new Vector3(-3.6f, transform.position.y, transform.position.z);
			}
			if(transform.position.x > 3.6f)
			{
				transform.position = new Vector3(3.6f, transform.position.y, transform.position.z);
			}
			if(transform.position.z < -4.1f)
			{
				transform.position = new Vector3(transform.position.x, transform.position.y, -4.1f);
			}
			if(transform.position.z > 4.1f)
			{
				transform.position = new Vector3(transform.position.x, transform.position.y, 4.1f);
			}
			
			if(Mathf.Abs(pitchRawMouse) > 0.3f)
			{
				pitch += turnSpeed * Time.deltaTime * pitchRawMouse;
			}
			
			if(pitch > 70f)
			{
				pitch = 70f;
			}
			if(pitch < -70f)
			{
				pitch = -70f;
			}
			
			transform.localRotation = Quaternion.Euler(pitch, heading, 0f);
			
			//Collect
			if(Input.GetButtonDown("Fire1") && !firstFrame)
			{
				var clickedObject = GetClickedObject();
				if(clickedObject != null)
				{
					var junk = clickedObject.GetComponent<Junk>();
					if(junk != null)
					{
						selectedJunk = junk;
					}
				}
			}
		}
		
		firstFrame = false;
	}
	
	void OnGUI()
	{
		float scaleFactor = Screen.height / 1000.0f;
		GUI.matrix = Matrix4x4.TRS (new Vector3(Screen.width / 2.0f, Screen.height / 2.0f, 0.0f), Quaternion.identity, new Vector3 (scaleFactor, scaleFactor, 1.0f)); 

		if(skin)
		{
			GUI.skin = skin;
		}
		else
		{
			Debug.Log("GUI skin object missing.");
		}

		if(selectedJunk != null)
		{
			if(selectedJunk.isDestroyed)
			{
				selectedJunk = null;
			}
		}
		
		GUI.Label(new Rect(-785f, -485f, 320f, 200f), "", "textArea");
		GUI.Label(new Rect(-775f, -475f, 300f, 60f), "Score: " + score.ToString("#,##0"), "ScoreLabel");
		GUI.Label(new Rect(-775f, -415f, 300f, 60f), "Will: " + willingness.ToString("#,##0"), "ScoreLabel");
		GUI.Label(new Rect(-775f, -355f, 300f, 60f), "Money: " + money.ToString("C0"), "ScoreLabel");
		
		if(gameMessageTimer > 0.0f)
		{
			GUI.Label(new Rect(-465f, -405f, 930f, 80f), "", "textArea");
			GUI.Label(new Rect(-450f, -395f, 910f, 60f), gameMessage, "CenterLabel");
		}
		
		if(goalTimeRemaining > 0.0f)
		{
			GUI.Label(new Rect(465f, -405f, 320f, 140f), "", "textArea");
			GUI.Label(new Rect(475f, -395f, 300f, 60f), goalCountRemaining + " " + goalJunkType, "RightLabel");
			GUI.Label(new Rect(475f, -335f, 300f, 60f), goalTimeRemaining.ToString("0.0"), "RightLabel");
		}
		
		if(errorTimer > 0.0f)
		{
			GUI.Label(new Rect(-510f, 390f, 1020f, 80f), "", "textArea");
			GUI.Label(new Rect(-500f, 400f, 1020f, 60f), errorMessage, "ErrorLabel");
		}

		if(score > winScore && winScore != 0)
		{
			Time.timeScale = 0.0f;
			
			GUI.Label(new Rect(-510f, -130f, 1020f, 140f), "", "textArea");
			GUI.Label(new Rect(-500f, -120f, 1000f, 60f), "Congratulations! You are well on your way to a", "CenterLabel");
			GUI.Label(new Rect(-500f, -60f, 1000f, 60f), "minimalist lifestyle. Enjoy your newfound freedom!", "CenterLabel");
			
			if(GUI.Button(new Rect(-400f, 100f, 350f, 100f), "Restart"))
			{
				winScore = 0;
				Time.timeScale = 1.0f;
				SceneManager.LoadScene("Playfield");
			}
			if(GUI.Button(new Rect(50f, 100f, 350f, 100f), "Keep Playing"))
			{
				Time.timeScale = 1.0f;
				winScore = 0;
			}
		}
		
		
		if(selectedJunk == null)
		{
			feelingMessage = null;
		}

		if(selectedJunk != null && Time.timeScale > 0f)
		{
			if(feelingMessage == null)
			{
				feelingMessage = EvaluateFeeling(selectedJunk);
			}

			GUI.Label(new Rect(-260f, -430f, 520f, 560f), "", "textArea");
			GUI.Label(new Rect(-200f, -420f, 400f, 60f), selectedJunk.junkType, "CenterLabel");
			if(selectedJunk.icon != null)
			{
				GUI.DrawTexture(new Rect(-200f, -360f, 400f, 400f), selectedJunk.icon);
			}
			GUI.Label(new Rect(-250f, 40f, 500f, 60f), selectedJunk.flavorText, "FlavorText");

			GUI.Label(new Rect(-510f, 140f, 1020f, 80f), "", "textArea");
			if(selectedJunk.isSelling)
			{
				GUI.Label(new Rect(-500f, 150f, 1000f, 60f), "This item is listed on eJunk.", "CenterLabel");
			}
			else
			{
				GUI.Label(new Rect(-500f, 150f, 1000f, 60f), feelingMessage, "CenterLabel");
			}
			
			if(GUI.Button(new Rect(-350f, 230f, 200f, 100f), "Keep") || Input.GetKeyDown(KeyCode.Escape))
			{
				selectedJunk = null;
			}
			GUI.Label(new Rect(-350f, 310f, 200f, 100f), "[ESC]", "CenterLabel");
			
			var trashCaption = goalTimeRemaining > 0f ? "Give" : "Trash";
			if(GUI.Button(new Rect(-100f, 230f, 200f, 100f), trashCaption) || Input.GetKeyDown(KeyCode.Space))
			{
				if(CanTrash(selectedJunk))
				{
					if(goalTimeRemaining > 0f)
					{
						if(selectedJunk.junkType == goalJunkType)
						{
							goalCountRemaining--;
						}
					}
					
					selectedJunk.GetRidOfIt(0);
					AudioSource.PlayClipAtPoint(trashSound, Vector3.zero, 0.5f);
					selectedJunk = null;
				}
				else
				{
					errorMessage = "That's too important to me!";
					errorTimer = 3.0f;
					AudioSource.PlayClipAtPoint(errorSound, Vector3.zero, 0.25f);
				}
			}
			GUI.Label(new Rect(-100f, 310f, 200f, 100f), "[Space]", "CenterLabel");

			if(GUI.Button(new Rect(150f, 230f, 200f, 100f), "Sell") || Input.GetKeyDown(KeyCode.E))
			{
				if(CanSell(selectedJunk))
				{
					selectedJunk.isSelling = true;
					selectedJunk = null;
				}
				else
				{
					errorMessage = "That's too important to me!";
					errorTimer = 3.0f;
					AudioSource.PlayClipAtPoint(errorSound, Vector3.zero, 0.25f);
				}
			}
			GUI.Label(new Rect(150f, 310f, 200f, 100f), "[E]", "CenterLabel");
		}
	}
	
	public void PlayMoneySound()
	{
		AudioSource.PlayClipAtPoint(moneySound, Vector3.zero, 1.0f);
	}
	
	public void PlayBonusSound()
	{
		AudioSource.PlayClipAtPoint(bonusSound, Vector3.zero, 1.0f);
	}

	public void SetGameMessage(string message)
	{
		gameMessage = message;
		gameMessageTimer = 3.0f;
	}
	
	public void SetErrorMessage(string message)
	{
		errorMessage = message;
		errorTimer = 3.0f;
		AudioSource.PlayClipAtPoint(errorSound, Vector3.zero, 0.25f);
	}
	
	private bool CanTrash(Junk junk)
	{
		return willingness >= junk.sentiment * 5;
	}
	
	private bool CanSell(Junk junk)
	{
		return willingness >= (junk.sentiment * 5) - junk.money;
	}
	
	private string EvaluateFeeling(Junk junk)
	{
		
		if(!CanSell(junk))
		{
			return needMessages[Random.Range(0, needMessages.Length)];
		}
		
		if(!CanTrash(junk))
		{
			var willEffectIfSold = junk.GetEffectOnWillingness(willingness, junk.money);
			if(willEffectIfSold > 0)
			{
				return sellMessages[Random.Range(0, sellMessages.Length)];
			}
			else
			{
				return willDownMessages[Random.Range(0, willDownMessages.Length)];
			}
		}

		int willEffectIfTrash = junk.GetEffectOnWillingness(willingness, 0);
		if(willEffectIfTrash > 0)
		{
			return trashMessages[Random.Range(0, sellMessages.Length)];
		}
		else
		{
			return willDownMessages[Random.Range(0, willDownMessages.Length)];
		}
	}

	private GameObject GetClickedObject()
	{
		var ray = Camera.main.ScreenPointToRay(Input.mousePosition);
		RaycastHit hit;
		
		if(Physics.Raycast(ray, out hit, 2.0f))
		{
			return hit.transform.gameObject;
		}
		
		return null;
	}
}
