using UnityEngine;
using System.Collections;

public class SceneManager : MonoBehaviour 
{
	private bool isLoading = false;
	private bool fading = false;
	private bool destroyMusic = false;
	private string nextScene;
	
	public float faderSpeed = 1.0f;
	
	static public void LoadScene(string scene)
	{
		LoadScene(scene, false);
	}

	static public void LoadScene(string scene, bool destroyMusic)
	{
		SceneManager manager = (SceneManager)FindObjectOfType(typeof(SceneManager));
		
		if(manager != null)
		{
			manager.LoadSceneInternal(scene, destroyMusic);
		}
		else
		{
			if(destroyMusic)
			{
				MenuMusic music = (MenuMusic)FindObjectOfType(typeof(MenuMusic));
				Destroy(music);
			}
			LoadLevel(scene);
		}
	}

	// Use this for initialization
	void Start () {
	
	}
	
	void Update () 
	{
		if(isLoading)
		{
			if(!fading && IsLevelReady(nextScene))
			{
				FadeOut();
			}
			else
			{
				LoadingStatusGUI loadingStatus = (LoadingStatusGUI)FindObjectOfType(typeof(LoadingStatusGUI));
				if(loadingStatus != null)
				{
					loadingStatus.statusScene = nextScene;
					loadingStatus.showSceneStatus = true;
				}
			}

			if(fading)
			{
				SceneTransition fader = (SceneTransition)GetComponent(typeof(SceneTransition));
				if(!fader || fader.completed)
				{
					if(destroyMusic)
					{
						MenuMusic music = (MenuMusic)FindObjectOfType(typeof(MenuMusic));
						Destroy(music);
					}
					LoadLevel(nextScene);
				}
			}
		}
	}
	
	private void LoadSceneInternal(string scene, bool destroyMusic)
	{
		nextScene = scene;
		this.destroyMusic = destroyMusic;
		isLoading = true;
	}
	
	private void FadeOut()
	{
		fading = true;
		SceneTransition fader = (SceneTransition)GetComponent(typeof(SceneTransition));
		if(fader)
		{
			fader.transitionType = TransitionType.FadeOut;
			fader.speed = faderSpeed;
			fader.Clear();
			fader.triggered = true;
		}
	}
	
	static private void LoadLevel(string sceneName)
	{
		if(Application.CanStreamedLevelBeLoaded(sceneName))
		{
			Application.LoadLevel(sceneName);
		}
	}

	static public bool IsLevelReady(string sceneName)
	{
		return Application.CanStreamedLevelBeLoaded(sceneName);
	}
}
